<?php

namespace Litecms\Contact\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Contact\Models\AccountContact;


class AccountContactAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, AccountContact $account_contact, array $request = [])
    {
        $this->model = $account_contact;

        $function = Str::camel($action);
        event('litecms.contact.account_contact.action.' . $action . 'ing', [$account_contact]);
        $data =  $this->$function($account_contact, $request);
        event('litecms.contact.account_contact.action.' . $action . 'ed', [$account_contact]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(AccountContact $account_contact, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $account_contact = $account_contact->create($attributes);
        return $account_contact;
    }

    public function update(AccountContact $account_contact, array $request)
    {
        $attributes = $request;
        $account_contact->update($attributes);
        return $account_contact;
    }

    public function delete(AccountContact $account_contact, array $request)
    {
        $account_contact->delete();
        return $account_contact;
    }

    public function copy(AccountContact $account_contact, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $account_contact = $account_contact->replicate();
            $account_contact->created_at = Carbon::now();
            $account_contact->save();
            return $account_contact;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $account_contact->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $account_contact;
    }


}
