<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Contact\Http\Requests\AccountActionsRequest;
use Litecms\Contact\Models\AccountActions;

/**
 * Admin web controller class.
 */
class AccountActionsController extends BaseController
{

    /**
     * Action controller function for account.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AccountActionsRequest $request, $action)
    {
        try {
            $account = AccountActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contact::account.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/account/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/account/' . $action))
                ->redirect();
        }
    }
}
