<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Contact\Actions\AccountContactAction;
use Litecms\Contact\Http\Requests\AccountContactActionRequest;
use Litecms\Contact\Http\Resources\AccountContactResource;
use Litecms\Contact\Models\AccountContact;

/**
 * Admin web controller class.
 */
class AccountContactActionController extends BaseController
{

    /**
     * Action controller function for account_contact.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AccountContactActionRequest $request, AccountContact $account_contact, $action)
    {
        try {
            $account_contact = AccountContactAction::run($request, $account_contact, $action);

            $data = new AccountContactResource($account_contact);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('contact::account_contact.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/account_contact/' . $account_contact->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/account_contact/' . $account_contact->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
