<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Contact\Http\Requests\AccountContactActionsRequest;
use Litecms\Contact\Models\AccountContactActions;

/**
 * Admin web controller class.
 */
class AccountContactActionsController extends BaseController
{

    /**
     * Action controller function for account_contact.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AccountContactActionsRequest $request, $action)
    {
        try {
            $account_contact = AccountContactActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contact::account_contact.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/account_contact/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/account_contact/' . $action))
                ->redirect();
        }
    }
}
