<?php

namespace Litecms\Contact\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Contact\Forms\AccountContact as AccountContactForm;
use Litecms\Contact\Http\Requests\AccountContactResourceRequest;
use Litecms\Contact\Http\Resources\AccountContactResource;
use Litecms\Contact\Http\Resources\AccountContactsCollection;
use Litecms\Contact\Models\AccountContact;
use Litecms\Contact\Models\AccountContactActions;


/**
 * Resource controller class for account_contact.
 */
class AccountContactResourceController extends BaseController
{

    /**
     * Initialize account_contact resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = AccountContactForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('litecms.contact.modules'), 'contact', guard_url('contact'));
    }

    /**
     * Display a list of account_contact.
     *
     * @return Response
     */
    public function index(AccountContactResourceRequest $request)
    {
        $request = $request->all();
        $page = AccountContactActions::run('paginate', $request);

        $data = new AccountContactsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('contact::account_contact.names'))
            ->view('contact::account_contact.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display account_contact.
     *
     * @param Request $request
     * @param Model   $account_contact
     *
     * @return Response
     */
    public function show(AccountContactResourceRequest $request, AccountContact $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AccountContactResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('contact::account_contact.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('contact::account_contact.show')
            ->output();
    }

    /**
     * Show the form for creating a new account_contact.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AccountContactResourceRequest $request, AccountContact $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AccountContactResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('contact::account_contact.name'))
            ->view('contact::account_contact.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new account_contact.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AccountContactResourceRequest $request, AccountContact $model)
    {
        try {
            $request = $request->all();
            $model = AccountContactAction::run('store', $model, $request);
            $data = new AccountContactResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('contact::account_contact.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/account_contact/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/contact/account_contact'))
                ->redirect();
        }

    }

    /**
     * Show account_contact for editing.
     *
     * @param Request $request
     * @param Model   $account_contact
     *
     * @return Response
     */
    public function edit(AccountContactResourceRequest $request, AccountContact $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new AccountContactResource($model);
        // return view('contact::account_contact.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('contact::account_contact.name'))
            ->view('contact::account_contact.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the account_contact.
     *
     * @param Request $request
     * @param Model   $account_contact
     *
     * @return Response
     */
    public function update(AccountContactResourceRequest $request, AccountContact $model)
    {
        try {
            $request = $request->all();
            $model = AccountContactAction::run('update', $model, $request);
            $data = new AccountContactResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contact::account_contact.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contact/account_contact/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/account_contact/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the account_contact.
     *
     * @param Model   $account_contact
     *
     * @return Response
     */
    public function destroy(AccountContactResourceRequest $request, AccountContact $model)
    {
        try {

            $request = $request->all();
            $data = new AccountContactResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('contact::account_contact.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contact/account_contact/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/account_contact/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
