<?php

namespace Litecms\Contact\Policies;

use Litecms\Contact\Models\Account;
use Litepie\User\Interfaces\UserPolicyInterface;

trait AccountAction
{

    /**
     * Determine if the given user can approve the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Account $account)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('contact.account.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Account $account) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('contact.account.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Account $account)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('contact.account.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Account $account)
    {


        if ($authUser->canDo('contact.account.action.delete')) {
            return true;
        }

        return false;
    }


}
