<?php

namespace Litecms\Contact\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Contact\Models\AccountContact;

class AccountContactPolicy
{

    use AccountContactAction;

    /**
     * Determine if the given user can view the account_contact.
     *
     * @param UserPolicyInterface $authUser
     * @param AccountContact $account_contact
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AccountContact $account_contact)
    {
        if ($authUser->canDo('contact.account_contact.view') && $authUser->isAdmin()) {
            return true;
        }

        return $account_contact->user_id == user_id() && $account_contact->user_type == user_type();
    }

    /**
     * Determine if the given user can create a account_contact.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('contact.account_contact.create');
    }

    /**
     * Determine if the given user can update the given account_contact.
     *
     * @param UserPolicyInterface $authUser
     * @param AccountContact $account_contact
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AccountContact $account_contact)
    {
        if ($authUser->canDo('contact.account_contact.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $account_contact->user_id == user_id() && $account_contact->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given account_contact.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AccountContact $account_contact)
    {
        return $account_contact->user_id == user_id() && $account_contact->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given account_contact.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AccountContact $account_contact)
    {
        if ($authUser->canDo('contact.account_contact.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given account_contact.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AccountContact $account_contact)
    {
        if ($authUser->canDo('contact.account_contact.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
