<?php

namespace Litecms\Contact\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Contact\Models\Account;

class AccountPolicy
{

    use AccountAction;

    /**
     * Determine if the given user can view the account.
     *
     * @param UserPolicyInterface $authUser
     * @param Account $account
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Account $account)
    {
        if ($authUser->canDo('contact.account.view') && $authUser->isAdmin()) {
            return true;
        }

        return $account->user_id == user_id() && $account->user_type == user_type();
    }

    /**
     * Determine if the given user can create a account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('contact.account.create');
    }

    /**
     * Determine if the given user can update the given account.
     *
     * @param UserPolicyInterface $authUser
     * @param Account $account
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Account $account)
    {
        if ($authUser->canDo('contact.account.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $account->user_id == user_id() && $account->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Account $account)
    {
        return $account->user_id == user_id() && $account->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Account $account)
    {
        if ($authUser->canDo('contact.account.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given account.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Account $account)
    {
        if ($authUser->canDo('contact.account.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
